#
# spec file for package libpff
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libpff
%define lname	libpff1
%define timestamp 20161119
Version:        0~%timestamp
Release:        bp153.1.15
Summary:        Library and tools to access Microsoft PFF and OFF format files
License:        LGPL-3.0+ and GFDL-1.1+ and GFDL-1.3+
Group:          Productivity/File utilities
Url:            https://github.com/libyal/libpff/wiki
Source:         https://github.com/libyal/libpff/releases/download/%{timestamp}/libpff-experimental-%{timestamp}.tar.gz
Source2:        PFF_Forensics_-_analyzing_the_horrible_reference_file_format.pdf
Source3:        PFF_forensics_-_e-mail_and_appoinment_falsification_analysis.pdf
Source4:        Personal_Folder_File_PFF_format.pdf
Source5:        MAPI_definitions.pdf
Source6:        libpff-libfdata.pdf
Patch1:         pkgconfig.diff

BuildRequires:  pkg-config
BuildRequires:  python-devel
# use factory packages if available
%if 0%{?suse_version} > 1230
BuildRequires:  pkgconfig(libbfio) >= 20130721
BuildRequires:  pkgconfig(libcdata)
BuildRequires:  pkgconfig(libcfile) >= 20130609
BuildRequires:  pkgconfig(libclocale) >= 20130609
BuildRequires:  pkgconfig(libcnotify) >= 20120425
BuildRequires:  pkgconfig(libcpath) >= 20130609
BuildRequires:  pkgconfig(libcsplit) >= 20130609
BuildRequires:  pkgconfig(libcstring) >= 20120425
BuildRequires:  pkgconfig(libcsystem) >= 20120425
BuildRequires:  pkgconfig(libcthreads)
BuildRequires:  pkgconfig(libfcache) >= 20120405
BuildRequires:  pkgconfig(libfdata) >= 20120405
BuildRequires:  pkgconfig(libfdatetime) >= 20120522
BuildRequires:  pkgconfig(libfguid) >= 20120426
BuildRequires:  pkgconfig(libfvalue) >= 20120428
BuildRequires:  pkgconfig(libfwnt) >= 20120426
BuildRequires:  pkgconfig(libuna) >= 20120425
%endif
# fails to build with factory package, use internal
# verified 2/14/2017
#BuildRequires:  pkgconfig(libcerror) >= 20120425
#BuildRequires:  pkgconfig(libfmapi) >= 20120405
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libpff is a library to access the Personal Folder File (PFF) and the
Offline Folder File (OFF) format. These are used in several file
Types: PAB (Personal Address Book), PST (Personal Storage Table) and
OST (Offline Storage Table).

%package -n %lname
Summary:        Library to access Microsoft PFF and OFF format files
License:        LGPL-3.0+
Group:          System/Libraries

%description -n %lname
libpff is a library to access the Personal Folder File (PFF) and the
Offline Folder File (OFF) format. These are used in several file
Types: PAB (Personal Address Book), PST (Personal Storage Table) and
OST (Offline Storage Table).

%package tools
Summary:        Tools to access Microsoft PST and OST files
License:        LGPL-3.0+
Group:          Productivity/File utilities
Requires:       %lname = %version

%description tools
Tools to access the Personal Folder File (PFF) and the Offline Folder
File (OFF) format. These are used in several file types: PAB
(Personal Address Book), PST (Personal Storage Table) and OST
(Offline Storage Table).

%package devel
Summary:        Development files for libpff, a PFF/OFF file format library
License:        LGPL-3.0+ and GFDL-1.1+ and GFDL-1.3+
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libpff is a library to access the Personal Folder File (PFF) and the
Offline Folder File (OFF) format. These are used in several file
Types: PAB (Personal Address Book), PST (Personal Storage Table) and
OST (Offline Storage Table).

This subpackage contains libraries and header files for developing
applications that want to make use of libpff.

%package -n python-%name
Summary:        Python bindings for libpff, a PFF/OFF file format parser
License:        LGPL-3.0+
Group:          Development/Libraries/Python
Requires:       python

%description -n python-%name
Python bindings for libpff, which can read Personal Folder File (PFF)
and Offline Folder File (OFF) formats.

%prep
%setup -qn libpff-%timestamp
%patch -P 1 -p1
cp "%{S:2}" "%{S:3}" "%{S:4}" "%{S:5}" "%{S:6}" .

%build
%configure --disable-static --enable-wide-character-type --enable-python
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
find "%buildroot" -name "*.la" -delete

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog
%_libdir/libpff.so.*

%files tools
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog
%_bindir/pff*
%_mandir/man1/pff*.1*

%files devel
%defattr(-,root,root)
%doc AUTHORS COPYING README ChangeLog
%doc MAPI_definitions.pdf
%doc PFF_Forensics_-_analyzing_the_horrible_reference_file_format.pdf
%doc PFF_forensics_-_e-mail_and_appoinment_falsification_analysis.pdf
%doc Personal_Folder_File_*.pdf
%_includedir/libpff.h
%_includedir/libpff/
%_libdir/libpff.so
%_libdir/pkgconfig/libpff.pc
%_mandir/man3/libpff.3*

%files -n python-%name
%defattr(-,root,root)
%python_sitearch/pypff.so

%changelog
* Wed Feb 15 2017 Greg.Freemyer@gmail.com
- Updated to v0~20161119
  * changes only provided in gitlog
- Renamed Personal_Folder_File_PFF_format.pdf to meet new naming rules
- correct URL and Source fields to the new github location
- Clean-up BuildRequires to use external packages as feasible
* Mon Oct 17 2016 jengelh@inai.de
- Add pkgconfig.diff; adds libbfio as a require into the .pc file
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- updated to v0~20131018
  * worked on python bindings
  * updated dependencies
  * worked on setup.py, largely for MSI builds
  * code clean up
  * added libcthreads build support
  * worked tests
  * refactored local descriptors
  * worked on compressed OST support
  - local descriptors
  - table reference
  - data array
  - table reference
  * worked on recovery in compressed OST files
  * updated dependencies
  * worked on record entry values array number out of bounds issue
  * refactored table index values to use libcdata array
  * fixed invalid return code in error path
  * worked on fixing out of bounds read of name to id map string in an error
  toloreant way
  * Added is corrupted function
  * worked on name to id map string out of bounds issue
  * worked on record entry values array number out of bounds issue
  * Worked on 64-bit 4k pages support
  * Worked on item recovery
- Clean-up BuildRequires to use external packages as feasible
* Wed Jul 31 2013 Greg.Freemyer@gmail.com
- update to v0~20130722
  * major refactor of code, packaged redesignated experimental
  * Worked on compressed OST support
  * worked on pypff
  * worked on tests
  * fix for handling floating point values in item file
  * updated dependencies
  * worked on API by_utf8_name and by_utf16_name functions
  * worked on libcdata rewrite
  * worked on libfdata update
  * worked on 64-bit 4k page file format support
  * bug fixes in error path
  * improved debug output
  * pffexport:
  - worked on IPM.DistList support
  - added message flags
  - improved output of flag types
  * libfmapi
  - improved debug output
  - fixes in error code paths
  * tests:
  - added pffinfo test
  * 2013 update
- changed to gz compression to simplyfy download/convert
- use all libyal factory packages possible
* Mon Apr 29 2013 kaanozdincer@gmail.com
- Make specfile more consistent with the other Joachim Metz packages.
- Move developer docs to devel package.
* Fri Apr  5 2013 jengelh@inai.de
- Cleanups: Set RPM group, summary and description metadata
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
* Wed Apr  3 2013 Greg.Freemyer@gmail.com
- Put documentation in -devel; do not bloat the shlib package
- Set licenses in each sub-package
- Remove unused %%py_requires
* Mon Apr  1 2013 Greg.Freemyer@gmail.com
- initial package (version 0.0.0~20120802) - alpha quality software
